package com.inspect.metadata.alg.service.impl;

import com.inspect.metadata.alg.domain.BasedataAlg;
import com.inspect.metadata.alg.mapper.BasedataAlgMapper;
import com.inspect.metadata.alg.service.IBasedataAlgService;
import com.inspect.base.core.utils.DateUtils;

import java.util.List;

import org.springframework.stereotype.Service;

@Service
public class BasedataAlgServiceImpl implements IBasedataAlgService {
    private final BasedataAlgMapper basedataAlgMapper;

    public BasedataAlgServiceImpl(BasedataAlgMapper basedataAlgMapper) {
        this.basedataAlgMapper = basedataAlgMapper;
    }

    public BasedataAlg selectBasedataAlgByAlgId(Long algId) {
        return this.basedataAlgMapper.selectBasedataAlgByAlgId(algId);
    }

    public List<BasedataAlg> selectBasedataAlgList(BasedataAlg basedataAlg) {
        return this.basedataAlgMapper.selectBasedataAlgList(basedataAlg);
    }

    public int insertBasedataAlg(BasedataAlg basedataAlg) {
        basedataAlg.setCreateTime(DateUtils.getNowDate());
        return this.basedataAlgMapper.insertBasedataAlg(basedataAlg);
    }

    public int updateBasedataAlg(BasedataAlg basedataAlg) {
        basedataAlg.setUpdateTime(DateUtils.getNowDate());
        return this.basedataAlgMapper.updateBasedataAlg(basedataAlg);
    }

    public int deleteBasedataAlgByAlgIds(Long[] algIds) {
        return this.basedataAlgMapper.deleteBasedataAlgByAlgIds(algIds);
    }

    public int deleteBasedataAlgByAlgId(Long algId) {
        return this.basedataAlgMapper.deleteBasedataAlgByAlgId(algId);
    }

    public List<BasedataAlg> getAlgTypeList() {
        return this.basedataAlgMapper.getAlgTypeList();
    }

    public List<BasedataAlg> selectBasedataAlgTypeList() {
        return this.basedataAlgMapper.selectBasedataAlgTypeList();
    }

    public int checkAlgNameIsExist(String algName, String algId) {
        return this.basedataAlgMapper.checkAlgNameIsExist(algName, algId);
    }
}
